@@ -1,6 +1,6 @@
 from datetime import datetime, date, time
 from sqlalchemy import create_engine, event
-from sqlalchemy.orm import scoped_session, sessionmaker, aliased, mapper
+from sqlalchemy.orm import scoped_session, sessionmaker, aliased, mapper, relationship
 from sqlalchemy.dialects import mysql
 from sqlalchemy import exists, desc, text, and_
 from sqlalchemy.inspection import inspect
