@@ -114,8 +114,7 @@ class Selenium(Scraper):
                     EC.presence_of_element_located((By.XPATH, path))
                 )
             except Exception as ex:
-                if is_error is True:
-                    raise ex
+                if is_error is True: raise NoSuchElementException(msg=f'Element with xpath {path} was not found')
                 else: return False
         else:
             try:
@@ -160,8 +159,8 @@ class Selenium(Scraper):
         else:
             return None
 
-    def on_hover(self, path: str, element: any, is_error: bool=True) -> None:
-        element = self.xPath(element=element, path=path, is_error=is_error)
+    def on_hover(self, path: str, element: any, is_error: bool=True, timeout: int=0) -> None:
+        element = self.xPath(element=element, path=path, is_error=is_error, timeout=timeout)
         ActionChains(self.driver).move_to_element(element).perform()
 
     def on_click_and_hold(self, path: str, seconds: float, element: any=None, timeout: int=0, is_error: bool=True) -> None:
